import { Module } from '@nestjs/common';
import { CqrsModule } from '@nestjs/cqrs';
import { DatabaseModule } from '../database/database.module';
import { AuthController } from './adapters/primaries/auth.controller';
import { CreateAuthUseCase } from './domain/usecases/create-auth.usecase';
import { ValidateAuthUseCase } from './domain/usecases/validate-auth.usecase';
import { AuthProfile } from './mappers/auth.profile';
import { AuthRepository } from './adapters/secondaries/auth.repository';
import { UpdateUsernameUseCase } from './domain/usecases/update-username.usecase';
import { UsernameProfile } from './mappers/username.profile';
import { AddUsernameUseCase } from './domain/usecases/add-username.usecase';
import { UpdatePasswordUseCase } from './domain/usecases/update-password.usecase';
import { DeleteUsernameUseCase } from './domain/usecases/delete-username.usecase';
import { DeleteAuthUseCase } from './domain/usecases/delete-auth.usecase';

@Module({
  imports: [DatabaseModule, CqrsModule],
  controllers: [AuthController],
  providers: [
    AuthProfile,
    UsernameProfile,
    AuthRepository,
    ValidateAuthUseCase,
    CreateAuthUseCase,
    AddUsernameUseCase,
    UpdateUsernameUseCase,
    UpdatePasswordUseCase,
    DeleteUsernameUseCase,
    DeleteAuthUseCase,
  ],
  exports: [],
})
export class AuthModule {}
