import { CommandHandler } from '@nestjs/cqrs';
import { UsernameRepository } from '../../adapters/secondaries/username.repository';
import { UpdateUsernameCommand } from '../../commands/update-username.command';
import { Username } from '../entities/username';

@CommandHandler(UpdateUsernameCommand)
export class UpdateUsernameUseCase {
  constructor(private readonly _usernameRepository: UsernameRepository) {}

  async execute(command: UpdateUsernameCommand): Promise<Username> {
    const { uuid, username, type } = command.updateUsernameRequest;
    try {
      return await this._usernameRepository.updateWhere(
        {
          uuid_type: {
            uuid,
            type,
          },
        },
        {
          username,
        },
      );
    } catch (e) {
      throw e;
    }
  }
}
