import { QueryHandler } from '@nestjs/cqrs';
import { AuthRepository } from '../../adapters/secondaries/auth.repository';
import { ValidateAuthQuery } from '../../queries/validate-auth.query';
import { Auth } from '../entities/auth';
import * as bcrypt from 'bcrypt';
import { NotFoundException, UnauthorizedException } from '@nestjs/common';
import { UsernameRepository } from '../../adapters/secondaries/username.repository';

@QueryHandler(ValidateAuthQuery)
export class ValidateAuthUseCase {
  constructor(
    private readonly _authRepository: AuthRepository,
    private readonly _usernameRepository: UsernameRepository,
  ) {}

  async execute(validate: ValidateAuthQuery): Promise<Auth> {
    try {
      const username = await this._usernameRepository.findOne({
        username: validate.username,
      });
      const auth = await this._authRepository.findOne({
        uuid: username.uuid,
      });
      if (auth) {
        const isMatch = await bcrypt.compare(validate.password, auth.password);
        if (isMatch) return auth;
        throw new UnauthorizedException();
      }
      throw new NotFoundException();
    } catch (e) {
      throw new UnauthorizedException();
    }
  }
}
