import { classes } from '@automapper/classes';
import { AutomapperModule } from '@automapper/nestjs';
import { Test, TestingModule } from '@nestjs/testing';
import { UsernameRepository } from '../../adapters/secondaries/username.repository';
import { Username } from '../../domain/entities/username';
import { UpdateUsernameRequest } from '../../domain/dtos/update-username.request';
import { UpdateUsernameCommand } from '../../commands/update-username.command';
import { Type } from '../../domain/dtos/type.enum';
import { UpdateUsernameUseCase } from '../../domain/usecases/update-username.usecase';

const updateUsernameRequest: UpdateUsernameRequest = {
  uuid: 'bb281075-1b98-4456-89d6-c643d3044a91',
  username: 'johnny.doe@email.com',
  type: Type.EMAIL,
};
const updateUsernameCommand: UpdateUsernameCommand = new UpdateUsernameCommand(
  updateUsernameRequest,
);

const mockUsernameRepository = {
  updateWhere: jest.fn().mockResolvedValue(updateUsernameRequest),
};

describe('UpdateUsernameUseCase', () => {
  let updateUsernameUseCase: UpdateUsernameUseCase;

  beforeAll(async () => {
    const module: TestingModule = await Test.createTestingModule({
      imports: [AutomapperModule.forRoot({ strategyInitializer: classes() })],
      providers: [
        {
          provide: UsernameRepository,
          useValue: mockUsernameRepository,
        },
        UpdateUsernameUseCase,
      ],
    }).compile();

    updateUsernameUseCase = module.get<UpdateUsernameUseCase>(
      UpdateUsernameUseCase,
    );
  });

  it('should be defined', () => {
    expect(updateUsernameUseCase).toBeDefined();
  });

  describe('execute', () => {
    it('should update a username for email type', async () => {
      const updatedUsername: Username = await updateUsernameUseCase.execute(
        updateUsernameCommand,
      );

      expect(updatedUsername.username).toBe(updateUsernameRequest.username);
      expect(updatedUsername.type).toBe(updateUsernameRequest.type);
    });
  });
});
